"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _mysql = require("mysql2");

var _connect = _interopRequireDefault(require("./connect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const configure = (pool, config) => {
  const createGetConnectPromise = () => {
    let p;
    return () => {
      if (p === undefined) {
        p = (0, _connect.default)(pool);
      }

      return p;
    };
  };

  const {
    database,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    subscribersTableName,
    ...connectionOptions
  } = config;
  const props = {
    database: database,
    eventsTableName: eventsTableName !== null && eventsTableName !== void 0 ? eventsTableName : 'events',
    snapshotsTableName: snapshotsTableName !== null && snapshotsTableName !== void 0 ? snapshotsTableName : 'snapshots',
    secretsTableName: secretsTableName !== null && secretsTableName !== void 0 ? secretsTableName : 'secrets',
    subscribersTableName: subscribersTableName !== null && subscribersTableName !== void 0 ? subscribersTableName : 'subscribers',
    escape: _mysql.escape,
    escapeId: _mysql.escapeId,
    connectionOptions,
    createGetConnectPromise,
    getConnectPromise: createGetConnectPromise(),
    query: async sql => {
      await pool.getConnectPromise();
      if (pool.connection === undefined) throw new Error('Impossible state: connection must not be null');
      const connection = pool.connection;
      return await connection.query(sql);
    },
    execute: async sql => {
      await pool.getConnectPromise();
      if (pool.connection === undefined) throw new Error('Impossible state: connection must not be null');
      const connection = pool.connection;
      await connection.execute(sql);
    }
  };
  Object.assign(pool, props);
};

var _default = configure;
exports.default = _default;
//# sourceMappingURL=configure.js.map